@@ -1,8 +1,8 @@
 RMlines <-
   function(behavior,x){
     
-    targetindex<-dev.cur() 
-    targetindex<-recordPlot() 
+   # targetindex<-dev.cur() 
+    #targetindex<-recordPlot() 
     
     
    # l<-locator(1)
